@@ -300,13 +300,12 @@ if not os.path.exists(sh_script):
         /usr/bin/puppet apply --summarize \
                 --detailed-exitcodes \
                 --color=false \
-                --logdest syslog \
-                --logdest console \
                 --modulepath=/etc/puppet/modules:/usr/share/openstack-puppet/modules \
                 $TAGS \
                 $CHECK_MODE \
-                /etc/config.pp
-        rc=$?
+                /etc/config.pp \
+                2>&1 | logger -s -t puppet-user
+        rc=${PIPESTATUS[0]}
         set -e
         if [ $rc -ne 2 -a $rc -ne 0 ]; then
             exit $rc
@@ -552,6 +551,11 @@ for infile in infiles:
     with open(infile) as f:
         infile_data = json.load(f)
 
+    # if the contents of the file is None, we need should just create an empty
+    # data set see LP#1828295
+    if not infile_data:
+        infile_data = {}
+
     for k, v in iter(infile_data.items()):
         config_volumes = match_config_volumes(config_volume_prefix, v)
         config_hashes = [get_config_hash(volume_path) for volume_path in config_volumes]
